import QtQuick 1.0

//import qmlprocess 1.0
import quickwidgets 1.0

Item {
    property color trackColor: "#ffffff"
    property color albumColor: "#d0d0d0"
    property color artistColor: "#c0c0c0"
    property color noArtColor: "#202020"
    property int updateInterval: 5000
    property int albumSize: 64

    function parse(stdout) {
        var rx = /"([\S\s]*?)"/;
        var val=stdout.match(rx)
        if (val) {
            return val[1]
        }
        return ""
    }

    function updateLabels(stdout) {
        var val = parse(stdout)
        if (val) {
            var parts = val.split("\n");
            if (parts.length == 3) {
                title.text = parts[0]
                artist.text = parts[1]
                album.text = parts[2]
                return
            }
        }
        title.text = "";
        artist.text = "";
        album.text =  "";
    }

    function suspend() {
        updateinfo.stop()
    }

    function resume() {
        delay.start()
    }

    id: info
    property string command: "sh -c \"dbus-send --type=method_call --print-reply --dest=ru.somebody.someplayer / ru.somebody.someplayer.title_artist_album"
    property string artcommand: "sh -c \"dbus-send --type=method_call --print-reply --dest=ru.somebody.someplayer / ru.somebody.someplayer.albumart"


    Rectangle {
        id: artholder
        anchors.left:  parent.left
        anchors.leftMargin: 10
        width: albumSize
        height: albumSize
        color: noArtColor
        radius: 3

        Image {
            id: art
            fillMode: Image.PreserveAspectCrop
            source: ""
            anchors.fill: parent
        }
    }

    Column {
        spacing: 1
        anchors.left: artholder.right
        anchors.leftMargin: 10
        width: parent.width - artholder.width -30

        Text {
            id: title
            width:parent.width
            elide: Text.ElideRight
            font.pointSize: 11
            font.bold:  true
            color: trackColor
        }
        Text {
            id: artist
            color: artistColor
            font.pointSize: 10
        }
        Text {
            id: album
            font.pointSize: 8
            color: albumColor
        }
    }

    Process {
        id: dbus
        command: info.command

        onCompleted: { updateLabels(stdout) }
        onFailed: { updateLabels("") }
    }
    Process {
        id: dbusart
        command: info.artcommand

        onCompleted: { art.source = parse(stdout); }
        onFailed: { art.source = "" }
    }

    Timer {
        id: delay
        repeat: false
        interval: 500
        triggeredOnStart: false
        //running: runtime.isActiveWindow
        onTriggered: { updateinfo.restart() }
    }
    Timer {
        id: updateinfo
        repeat: true
        interval: updateInterval
        triggeredOnStart: true
        running: runtime.isActiveWindow
        onTriggered: { dbus.run();dbusart.run() }
    }

    Component.onCompleted: { updateinfo.start(); }
}
