import QtQuick 1.0
import quickwidgets 1.0

import "content"

Item {
    width:  270
    height:  150

    Rectangle {
        id: backgroundfill
        anchors.fill: parent
        opacity:  0.5
        color: "black"
        radius:  5
    }

    Text {
        id: note
        anchors.centerIn: parent
        visible: false
        text:  "someplayer is not running..."
        font.bold: true
        horizontalAlignment: Text.AlignHCenter
        font.pointSize: 10
        color: "white"
        Rectangle {
            color: "#606060"
            radius: 5
            width: 90
            height: 50
	    anchors.top: parent.bottom
            anchors.topMargin: 10
            anchors.horizontalCenter: parent.horizontalCenter
            Text { color: "white"; text: "Tap to start"
                font.pointSize: 11
                anchors.centerIn: parent
            }

            MouseArea {
                anchors.fill: parent
                onClicked: someplayer.run()
            }
            Process {
                id: someplayer
                command: "sh -c \"/usr/bin/someplayer &\""
                onCompleted: {
                    player.visible = true;
                    info.visible = true;
                    info.resume();
                    note.visible = false;
                }
                onFailed: {
                    player.visible = false;
                    info.visible = false;
                    info.suspend()
                    note.visible = true;
                }
            }

        }
    }

    Playlist {
        id: pl;
        width: parent.width;
        height: parent.height
        visible:  false
        z: 1
        onNewPlaylist: { visible = false }
    }
    TrackInfo {
        id: info
        width: parent.width
        height: parent.height-player.height-10
        anchors.top: parent.top
        anchors.topMargin: 5
        anchors.horizontalCenter: parent.horizontalCenter
        MouseArea {
            id: flipit
            anchors.fill: parent
            onClicked: {
                pl.visible = true;
            }
        }
    }

    Row {
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottomMargin: 5
        anchors.bottom: parent.bottom
        id: player
        spacing: 10
        Button {
            width:  48
            height:  48
            id: back
            anchors.bottom: parent.bottom
            buttonType: "prev"
            onPressed: {
                info.resume();
                pp.play()
            }
        }

        ToggleButton {
            id: pp
            width:  64
            height:  64
            onPressed: {
                info.resume();
            }
        }
        Button {
            id: stop
            buttonType: "stop"
            width:  64
            height:  64
            onPressed: {
                info.suspend()
                pp.pause()
            }
        }

        Button {
            width:  48
            height:  48
            id: fwd
            anchors.bottom: parent.bottom
            buttonType: "next"
            onPressed: {
                info.resume();
                pp.play()
            }
        }
    }

    Timer {
        id: checktimer
        interval:  20000
        triggeredOnStart: true
        repeat:  true
        running: runtime.isActiveWindow
        onTriggered:  {checker.run();}
    }

    Process {
        id: checker
        command: "sh -c \"ps -ef |grep someplayer |grep -v grep\""
        onCompleted: {
            player.visible = true;
            info.visible = true;
            info.resume();
            note.visible = false;
        }
        onFailed: {
            player.visible = false;
            info.visible = false;
            info.suspend()
            note.visible = true;
        }
    }

    Component.onCompleted: {
        checktimer.start()
    }
}

